.. module:: enaml.widgets.mdi_area

======================
enaml.widgets.mdi_area
======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    MdiArea


.. autoclass:: MdiArea
